@@ -8,11 +8,11 @@
 #include "contactselectionwidget.h"
 #include <QDebug>
 
-#include <AkonadiCore/EntityTreeModel>
-#include <AkonadiCore/ItemFetchJob>
-#include <AkonadiCore/ItemFetchScope>
-#include <AkonadiCore/RecursiveItemFetchJob>
-#include <AkonadiWidgets/CollectionComboBox>
+#include <Akonadi/CollectionComboBox>
+#include <Akonadi/EntityTreeModel>
+#include <Akonadi/ItemFetchJob>
+#include <Akonadi/ItemFetchScope>
+#include <Akonadi/RecursiveItemFetchJob>
 
 #include <KLocalizedString>
 
@@ -99,7 +99,7 @@ void ContactSelectionWidget::setAddGroupContact(bool addGroupContact)
 void ContactSelectionWidget::initGui()
 {
     auto layout = new QVBoxLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    layout->setContentsMargins({});
 
     mMessageLabel = new QLabel;
     layout->addWidget(mMessageLabel);
@@ -152,7 +152,7 @@ void ContactSelectionWidget::initGui()
     boxLayout->addWidget(mAddressBookContactsButton, 2, 0, Qt::AlignTop);
 
     auto addressBookLayout = new QVBoxLayout;
-    addressBookLayout->setContentsMargins(0, 0, 0, 0);
+    addressBookLayout->setContentsMargins({});
     addressBookLayout->addWidget(mAddressBookSelection);
     addressBookLayout->addWidget(mAddressBookSelectionRecursive);
 
